#!/bin/bash

################################################################################
# COPYRIGHT © 2018 OROLIA GROUP AND/OR ITS AFFILIATES.  ALL RIGHTS ARE STRICTLY
# RESERVED.  THIS SOURCE CODE CONTAINS PROPRIETARY AND CONFIDENTIAL INFORMATION
# AND DATA AND IS THE SOLE PROPERTY OF OROLIA GROUP AND/OR ITS AFFILIATES.
# THIS SOURCE CODE MUST NOT BE USED, DISSEMINATED, OR DISTRIBUTED EXCEPT FOR THE# AGREED PURPOSE.  UNAUTHORIZED USE, REPRODUCTION, OR ISSUE TO ANY THIRD PARTY
# IS NOT PERMITTED WITHOUT THE PRIOR WRITTEN CONSENT OF THE OROLIA GROUP.  THIS
# SOURCE CODE IS TO BE RETURNED TO THE OROLIA GROUP WHEN THE AGREED PURPOSE IS
# FULFILLED."
################################################################################

################################################################################
# Definitions 
################################################################################

# Maximum /home/spectracom/log/broadshield folder size limit
# Value below is defined for ALL LICENSES installed. Less is required for
# OPT-BSH only
THRESHOLD=10000  # For OPT-BSH only
THRESHOLD_MAX=180000  # For OPT-BSH with OPT-BSL or OP-BSD Debug mode

CURRENT=`du -s /home/spectracom/log/broadshield 2>>/dev/null | awk '{print $1}'`

BASE="/home/spectracom/log/broadshield"

NUMDIR=`/bin/ls -1rt $BASE 2>>/dev/null | /usr/bin/wc -l 2>> /dev/null`
echo "NUMDIR= $NUMDIR"
BROADSHIELD_LOG="/home/spectracom/log/broadshield.log"

DEBUG=0
DEBUG_LOG="/dev/null"

if [ "$DEBUG" -eq "1" ]; then
    DEBUG_LOG="/home/spectracom/log/broadshield_debug.log"
fi

################################################################################
# Functions 
################################################################################

function BroadShield_Log()
{
    cleantime=`date`;

    echo "BroadShield Clean script started at ${cleantime}" >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
    echo "BroadShield daemon status:" >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
    systemctl status broadshield >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
}

function BroadShield_Clean_Log()
{
    cleantime=`date`;

    echo "BroadShield Log clean operation started at ${cleantime}" >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
    echo "BroadShield Log directory size is ${1} Kbytes" >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
    echo "" >> ${BROADSHIELD_LOG} 
}

################################################################################
# Main 
################################################################################

if [ "$DEBUG" -eq "1" ]; then
    LOG="/home/spectracom/log/brdshd-clean.log"
    echo -n "Running brdshd-clean.sh at " >> $DEBUG_LOG
    date >> $DEBUG_LOG
fi

# Detect ANY BroadShield License
if [ ! -d "/home/spectracom/log/broadshield" ]; then
    echo "No BroadShield License" >> $DEBUG_LOG
    exit 0
fi

# Detect if OPT-BSL and OPT_BSD are present by counting licenses
LICENSES_FND=`DCS_GetOptions 0 | grep BroadShield | wc -l`
if [ "$LICENSES_FND" -gt 1 ]; then
    THRESHOLD=$THRESHOLD_MAX
fi

BroadShield_Log

# Perform clean if needed
if [ "$CURRENT" -gt "$THRESHOLD" ] ; then

    BroadShield_Clean_Log $CURRENT

    echo "Disk use is > $THRESHOLD" >> $DEBUG_LOG

    line=0

    /bin/ls -1rt $BASE | while read DIRNAME ; do
        (( ++line ))

        CURRENT=`du -s /home/spectracom/log/broadshield | awk '{print $1}'`

        if [ "$CURRENT" -lt "$THRESHOLD" ] ; then

            echo "Disk use is < $THRESHOLD" >> $DEBUG_LOG
            break;
        fi

        if [ "$line" -ge "$NUMDIR" ] ; then
            echo "Do not delete directory $line" >> $DEBUG_LOG
            break;
        fi

        /bin/rm -rf $BASE/$DIRNAME

        echo "Removing $BASE/$DIRNAME" >> $DEBUG_LOG

    done
else
    echo "NOTHING TO DO: Disk use is < $THRESHOLD" >> $DEBUG_LOG
fi

exit 0
